summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorsijanec <sijanecantonluka@gmail.com>2020-09-24 13:28:44 +0200
committersijanec <sijanecantonluka@gmail.com>2020-09-24 13:28:44 +0200
commit1365c1cd73800509eedf7f00cfb47ef6f20a19cd (patch)
treed63f52a4e670ffa92fa6301ba8478a3033ba2080
parentše en tracking feature (diff)
downloadbeziapp-1365c1cd73800509eedf7f00cfb47ef6f20a19cd.tar
beziapp-1365c1cd73800509eedf7f00cfb47ef6f20a19cd.tar.gz
beziapp-1365c1cd73800509eedf7f00cfb47ef6f20a19cd.tar.bz2
beziapp-1365c1cd73800509eedf7f00cfb47ef6f20a19cd.tar.lz
beziapp-1365c1cd73800509eedf7f00cfb47ef6f20a19cd.tar.xz
beziapp-1365c1cd73800509eedf7f00cfb47ef6f20a19cd.tar.zst
beziapp-1365c1cd73800509eedf7f00cfb47ef6f20a19cd.zip
-rw-r--r--assets/pages-src/misc/matomo.bvr52
-rwxr-xr-xdist/cache_name.txt2
-rwxr-xr-xdist/js/app.js56
-rwxr-xr-xdist/pages/about.html4
-rwxr-xr-xdist/sw.js4
-rw-r--r--global.bvr2
6 files changed, 50 insertions, 70 deletions
diff --git a/assets/pages-src/misc/matomo.bvr b/assets/pages-src/misc/matomo.bvr
index d57beb0..614e210 100644
--- a/assets/pages-src/misc/matomo.bvr
+++ b/assets/pages-src/misc/matomo.bvr
@@ -28,42 +28,32 @@ let promises_to_run_app = [
Promise.all(promises_to_run_app).then(() => {
-if (BEZIAPP_USERNAME == null || BEZIAPP_USERNAME == "") {
- var username_report = "neprijavljen.uporabnik";
-} else {
- var username_report = BEZIAPP_USERNAME;
-}
-if (BEZIAPP_LOPOLIS_USERNAME == null || BEZIAPP_LOPOLIS_USERNAME == "") {
- var lopolis_username_report = "NEPRIJAVLJENUPORABNIK";
-} else {
- var lopolis_username_report = BEZIAPP_LOPOLIS_USERNAME;
-}
-if (BEZIAPP_LANGUAGE == null || BEZIAPP_LANGUAGE == "") {
- var language_report = "unspecified_language";
-} else {
- var language_report = BEZIAPP_LANGUAGE
-}
-if (BEZIAPP_THEME == null || BEZIAPP_THEME == "") {
- var theme_report = "unspecified_theme";
-} else {
- var theme_report = BEZIAPP_THEME;
-}
-if (BEZIAPP_ERRORREPORTING == null || BEZIAPP_ERRORREPORTING == "") {
- var errorreporting_report = "unspecified-errorreporting";
-} else {
- var errorreporting_report = BEZIAPP_ERRORREPORTING;
-}
-
var _paq = window._paq = window._paq || [];
/* tracker methods like "setCustomDimension" should be called before "trackPageView" */
_paq.push(["setDocumentTitle", document.domain + "/" + document.title]);
_paq.push(["setDoNotTrack", true]);
- _paq.push(['setUserId', username_report]);
+
+ if (BEZIAPP_USERNAME == null || BEZIAPP_USERNAME == "") {
+ } else {
+ _paq.push(['setUserId', BEZIAPP_USERNAME]);
+ }
+ if (BEZIAPP_LOPOLIS_USERNAME == null || BEZIAPP_LOPOLIS_USERNAME == "") {
+ } else {
+ _paq.push(['setCustomVariable', 1, 'lopolis-username', BEZIAPP_LOPOLIS_USERNAME, 'visit']);
+ }
+ if (BEZIAPP_LANGUAGE == null || BEZIAPP_LANGUAGE == "") {
+ } else {
+ _paq.push(['setCustomVariable', 2, 'language', BEZIAPP_LANGUAGE, 'visit']);
+ }
+ if (BEZIAPP_THEME == null || BEZIAPP_THEME == "") {
+ } else {
+ _paq.push(['setCustomVariable', 3, 'theme', BEZIAPP_THEME, 'visit']);
+ }
+ if (BEZIAPP_ERRORREPORTING == null || BEZIAPP_ERRORREPORTING == "") {
+ } else {
+ _paq.push(['setCustomVariable', 4, 'errorreporting', BEZIAPP_ERRORREPORTING, 'visit']);
+ }
_paq.push(['enableHeartBeatTimer', 30]);
- _paq.push(['setCustomVariable', 1, 'lopolis-username', lopolis_username_report, 'visit']);
- _paq.push(['setCustomVariable', 2, 'language', language_report, 'visit']);
- _paq.push(['setCustomVariable', 3, 'theme', theme_report, 'visit']);
- _paq.push(['setCustomVariable', 4, 'errorreporting', errorreporting_report, 'visit']);
_paq.push(['setCustomVariable', 5, 'domain', window.location.host, 'visit']);
_paq.push(['trackPageView']);
_paq.push(['trackAllContentImpressions']);
diff --git a/dist/cache_name.txt b/dist/cache_name.txt
index 0d968c3..3d8b410 100755
--- a/dist/cache_name.txt
+++ b/dist/cache_name.txt
@@ -2,4 +2,4 @@
-///site-static-1.0.15.0-beta-a0a53be|||
+///site-static-1.0.15.1-beta-577c762|||
diff --git a/dist/js/app.js b/dist/js/app.js
index 783361e..026c17e 100755
--- a/dist/js/app.js
+++ b/dist/js/app.js
@@ -2,8 +2,8 @@
-const app_version = "1.0.15.0-beta";
-const previous_commit = "a0a53bec5f61439dece140798235114a0164e26d";
+const app_version = "1.0.15.1-beta";
+const previous_commit = "577c762cfc082bf78434af10b0910e43554cf634";
const BEZIAPP_UPDATE_INTERVAL = 300; // update vsakih 300 sekund
if ("serviceWorker" in navigator) {
@@ -156,42 +156,32 @@ let promises_to_run_app = [
Promise.all(promises_to_run_app).then(() => {
-if (BEZIAPP_USERNAME == null || BEZIAPP_USERNAME == "") {
- var username_report = "neprijavljen.uporabnik";
-} else {
- var username_report = BEZIAPP_USERNAME;
-}
-if (BEZIAPP_LOPOLIS_USERNAME == null || BEZIAPP_LOPOLIS_USERNAME == "") {
- var lopolis_username_report = "NEPRIJAVLJENUPORABNIK";
-} else {
- var lopolis_username_report = BEZIAPP_LOPOLIS_USERNAME;
-}
-if (BEZIAPP_LANGUAGE == null || BEZIAPP_LANGUAGE == "") {
- var language_report = "unspecified_language";
-} else {
- var language_report = BEZIAPP_LANGUAGE
-}
-if (BEZIAPP_THEME == null || BEZIAPP_THEME == "") {
- var theme_report = "unspecified_theme";
-} else {
- var theme_report = BEZIAPP_THEME;
-}
-if (BEZIAPP_ERRORREPORTING == null || BEZIAPP_ERRORREPORTING == "") {
- var errorreporting_report = "unspecified-errorreporting";
-} else {
- var errorreporting_report = BEZIAPP_ERRORREPORTING;
-}
-
var _paq = window._paq = window._paq || [];
/* tracker methods like "setCustomDimension" should be called before "trackPageView" */
_paq.push(["setDocumentTitle", document.domain + "/" + document.title]);
_paq.push(["setDoNotTrack", true]);
- _paq.push(['setUserId', username_report]);
+
+ if (BEZIAPP_USERNAME == null || BEZIAPP_USERNAME == "") {
+ } else {
+ _paq.push(['setUserId', BEZIAPP_USERNAME]);
+ }
+ if (BEZIAPP_LOPOLIS_USERNAME == null || BEZIAPP_LOPOLIS_USERNAME == "") {
+ } else {
+ _paq.push(['setCustomVariable', 1, 'lopolis-username', BEZIAPP_LOPOLIS_USERNAME, 'visit']);
+ }
+ if (BEZIAPP_LANGUAGE == null || BEZIAPP_LANGUAGE == "") {
+ } else {
+ _paq.push(['setCustomVariable', 2, 'language', BEZIAPP_LANGUAGE, 'visit']);
+ }
+ if (BEZIAPP_THEME == null || BEZIAPP_THEME == "") {
+ } else {
+ _paq.push(['setCustomVariable', 3, 'theme', BEZIAPP_THEME, 'visit']);
+ }
+ if (BEZIAPP_ERRORREPORTING == null || BEZIAPP_ERRORREPORTING == "") {
+ } else {
+ _paq.push(['setCustomVariable', 4, 'errorreporting', BEZIAPP_ERRORREPORTING, 'visit']);
+ }
_paq.push(['enableHeartBeatTimer', 30]);
- _paq.push(['setCustomVariable', 1, 'lopolis-username', lopolis_username_report, 'visit']);
- _paq.push(['setCustomVariable', 2, 'language', language_report, 'visit']);
- _paq.push(['setCustomVariable', 3, 'theme', theme_report, 'visit']);
- _paq.push(['setCustomVariable', 4, 'errorreporting', errorreporting_report, 'visit']);
_paq.push(['setCustomVariable', 5, 'domain', window.location.host, 'visit']);
_paq.push(['trackPageView']);
_paq.push(['trackAllContentImpressions']);
diff --git a/dist/pages/about.html b/dist/pages/about.html
index b501109..f51367f 100755
--- a/dist/pages/about.html
+++ b/dist/pages/about.html
@@ -76,7 +76,7 @@
<!-- One day in the future we may have sw cache version covered by this as well -->
<h5 class="subheader">
<x-su>version</x-su>
- 1.0.15.0-beta
+ 1.0.15.1-beta
</h5>
</div>
</div>
@@ -160,7 +160,7 @@
<div class="row">
<p>
<small>
- ^HEAD a0a53bec5f61439dece140798235114a0164e26d
+ ^HEAD 577c762cfc082bf78434af10b0910e43554cf634
</small>
</p>
</div>
diff --git a/global.bvr b/global.bvr
index 74d6617..209526a 100644
--- a/global.bvr
+++ b/global.bvr
@@ -1,3 +1,3 @@
<@?s bvr_include_path assets/pages-src/ assets/pages-src/misc/@>
<@?s latest_commit ?u 0 -1 ?i .git/refs/heads/dev@>
-<@?s app_version 1.0.15.0-beta@>
+<@?s app_version 1.0.15.1-beta@>
diff --git a/dist/sw.js b/dist/sw.js
index dcf9d10..f35932c 100755
--- a/dist/sw.js
+++ b/dist/sw.js
@@ -3,8 +3,8 @@
// Change version to cause cache refresh
-const static_cache_name = "site-static-1.0.15.0-beta-a0a53be";
-// commit before the latest is a0a53bec5f61439dece140798235114a0164e26d
+const static_cache_name = "site-static-1.0.15.1-beta-577c762";
+// commit before the latest is 577c762cfc082bf78434af10b0910e43554cf634
// Got them with find . -not -path '*/\.*' | sed "s/.*/\"&\",/" | grep -v sw.js
// sw.js NE SME BITI CACHAN, ker vsebuje verzijo!